@@ -9,6 +9,7 @@ from switchcraft.clients.ec2 import EC2Client
 from switchcraft.clients.rds import RDSClient
 from switchcraft.clients.sns import SNSClient
 from switchcraft.clients.s3 import S3Client
+from switchcraft.clients.sts import STSClient
 
 
 # Overriding '__all__' to ensure that public access to classes are controlled.
@@ -21,5 +22,6 @@ __all__ = [
     EC2Client,
     RDSClient,
     S3Client,
-    SNSClient
+    SNSClient,
+    STSClient
 ]
